@@ -127,7 +127,7 @@ func (a *RecordedApp) UpdateUsedGVsAndGKs(gvs []schema.GroupVersion, gks []schem
 	})
 }
 
-func (a *RecordedApp) CreateOrUpdate(labels map[string]string) error {
+func (a *RecordedApp) CreateOrUpdate(labels map[string]string, isDiffRun bool) error {
 	defer a.logger.DebugFunc("CreateOrUpdate").Finish()
 
 	app, foundMigratedApp, err := a.find(a.fqName())
@@ -152,7 +152,7 @@ func (a *RecordedApp) CreateOrUpdate(labels map[string]string) error {
 		return a.updateApp(app, labels)
 	}
 
-	return a.create(labels)
+	return a.create(labels, isDiffRun)
 }
 
 func (a *RecordedApp) find(name string) (*corev1.ConfigMap, bool, error) {
@@ -166,7 +166,7 @@ func (a *RecordedApp) find(name string) (*corev1.ConfigMap, bool, error) {
 	return cm, true, nil
 }
 
-func (a *RecordedApp) create(labels map[string]string) error {
+func (a *RecordedApp) create(labels map[string]string, isDiffRun bool) error {
 	configMap := &corev1.ConfigMap{
 		ObjectMeta: metav1.ObjectMeta{
 			Name:      a.name,
@@ -197,7 +197,13 @@ func (a *RecordedApp) create(labels map[string]string) error {
 		return err
 	}
 
-	_, err = a.coreClient.CoreV1().ConfigMaps(a.nsName).Create(context.TODO(), configMap, metav1.CreateOptions{})
+	createOpts := metav1.CreateOptions{}
+	if isDiffRun {
+		createOpts.DryRun = []string{metav1.DryRunAll}
+	}
+	app, err := a.coreClient.CoreV1().ConfigMaps(a.nsName).Create(context.TODO(), configMap, createOpts)
+
+	a.setMeta(*app)
 
 	return err
 }
@@ -216,7 +222,7 @@ func (a *RecordedApp) updateApp(existingConfigMap *corev1.ConfigMap, labels map[
 	return nil
 }
 
-func (a *RecordedApp) RenamePrevApp(prevAppName string, labels map[string]string) error {
+func (a *RecordedApp) RenamePrevApp(prevAppName string, labels map[string]string, isDiffRun bool) error {
 	defer a.logger.DebugFunc("RenamePrevApp").Finish()
 
 	app, foundMigratedApp, err := a.find(a.fqName())
@@ -263,7 +269,7 @@ func (a *RecordedApp) RenamePrevApp(prevAppName string, labels map[string]string
 		return a.renameConfigMap(app, a.name, a.nsName)
 	}
 
-	return a.create(labels)
+	return a.create(labels, isDiffRun)
 }
 
 func (a *RecordedApp) migrate(c *corev1.ConfigMap, labels map[string]string, newName string) error {
